Learn R Programming

dcifer (version 1.5.0)

revals: Parameter grid

Description

Precalculated parameter grids for a range of values of M (from 1 to 5).

Usage

revals

Arguments

Format

A list of length 5, where each element corresponds to a single value of M and is a matrix with M rows. Each column of a matrix is a r1 = ... = rM) combination.